@@ -1,6 +1,6 @@
 from sqlite3 import *
 
-conn = sqlite3.connect(db_file) #.db 
+conn = connect(db_file) #.db 
 
 cursor = conn.cursor()
 
